// Updated script.js: Only final results are processed and errors logged

window.SpeechRecognition = window.SpeechRecognition || window.webkitSpeechRecognition;

if (!window.SpeechRecognition) {
    alert("Speech recognition is not supported in this browser. Please use Chrome.");
} else {
    let recognition = new SpeechRecognition();
    recognition.continuous = true;
    recognition.interimResults = false;  // Only final results for clarity
    recognition.lang = "en-US";

    let output = document.getElementById("output");
    let isListening = false;
    let transcriptSoFar = "";
    let debugLog = "";

    // Helper to update the textarea with both transcript and debug log
    function updateOutput() {
        output.value = transcriptSoFar + "\n\nDEBUG LOG:\n" + debugLog;
    }

    document.getElementById("start").addEventListener("click", () => {
        if (!isListening) {
            recognition.start();
            isListening = true;
            debugLog += "\nDEBUG: Speech recognition started.";
            updateOutput();
            console.log("🚀 Speech recognition started...");
        }
    });

    document.getElementById("stop").addEventListener("click", () => {
        recognition.stop();
        isListening = false;
        debugLog += "\nDEBUG: Speech recognition stopped.";
        updateOutput();
        console.log("🛑 Speech recognition stopped.");
    });

    recognition.onresult = (event) => {
        let newTranscript = "";
        // Process only final results from event.resultIndex onward
        for (let i = event.resultIndex; i < event.results.length; i++) {
            let result = event.results[i];
            let text = result[0].transcript;
            let isFinal = result.isFinal;
            // Log only final events
            if (isFinal) {
                debugLog += `\nDEBUG: Result ${i} (final: ${isFinal}): ${text}`;
                newTranscript += text + " ";
            }
        }
        if (newTranscript.trim() !== "") {
            transcriptSoFar += newTranscript;
        }
        updateOutput();
    };

    recognition.onerror = (event) => {
        let errorMsg = "DEBUG: Speech recognition error: " + event.error;
        debugLog += "\n" + errorMsg;
        updateOutput();
        console.error(errorMsg);
        alert("Speech recognition error: " + event.error);
    };

    // Restart recognition if it ends unexpectedly while still listening
    recognition.onend = () => {
        debugLog += "\nDEBUG: Recognition ended.";
        updateOutput();
        if (isListening) {
            console.log("Restarting recognition...");
            recognition.start();
            debugLog += "\nDEBUG: Restarted recognition after onend event.";
            updateOutput();
        }
    };

    document.getElementById("clear").addEventListener("click", () => {
        transcriptSoFar = "";
        debugLog = "";
        updateOutput();
    });

    document.getElementById("save").addEventListener("click", () => {
        let now = new Date();
        let timestamp = now.toISOString().replace(/[-:T]/g, "").split(".")[0]; // Format: YYYYMMDD_HHMMSS
        let inputName = document.getElementById("filenameInput").value.trim();
        let prefix = inputName ? inputName.replace(/\s+/g, "_") : "Transcript_ATH";
        let filename = `${prefix}_${timestamp}.txt`;
        let blob = new Blob([transcriptSoFar + "\n\nDEBUG LOG:\n" + debugLog], { type: "text/plain" });
        let url = URL.createObjectURL(blob);
        chrome.downloads.download({
            url: url,
            filename: filename
        });
    });

    document.getElementById("selectAll").addEventListener("click", () => {
        output.select();
        document.execCommand("copy");
        alert("Text copied to clipboard!");
    });
}
